@@ -195,7 +195,7 @@ class InterfaceMeta(type):
 
 
 # noinspection PyPep8Naming
-def Interface(cls):
+def Interface(cls) -> typing.Iterable:
     """Decorator for classes that are interfaces.
 
     Declare an interface using the ``@Interface`` decorator, optionally add add attributes/methods to that class:
@@ -208,8 +208,9 @@ def Interface(cls):
                     pass
 
         You can choose whatever name you want for your interfaces, but we recommend you start the name with a capital "I".
-        Read more about interfaces in the :ref:`Interfaces` section."""
-    if type(cls) != type:
+        Read more about interfaces in the :ref:`Interfaces` section.
+    """
+    if not type(cls) == type:
         raise TypeError(f"@Interface must decorate a class, not {type(cls)}")
     interface_meta = InterfaceMeta(cls.__name__, cls.__bases__, dict(cls.__dict__))
     return interface_meta
